import { http } from "@/api/http";
import { httpErrorHandle } from "@/utils";
import { RequestHttpEnum, ContentTypeEnum } from "@/enums/httpEnum";

// 系统登录
export const postLogin = async (data: any) => {
  try {
    const res = await http(RequestHttpEnum.POST)(
      "/system/security/login",
      data
    );
    return res;
  } catch {
    httpErrorHandle();
  }
};

// 系统登出
export const getLogout = async () => {
  try {
    const res = await http(RequestHttpEnum.GET)("/system/security/logout");
    return res;
  } catch {
    httpErrorHandle();
  }
};

// 批量获取字典数据
export const postDictBatch = async (data: { categories: string[] }) => {
  try {
    const res = await http(RequestHttpEnum.POST)("/system/dict/batch", data);
    return res;
  } catch {
    httpErrorHandle();
  }
};

// 获取全部字典参数
export const getDictAll = async () => {
  try {
    const res = await http(RequestHttpEnum.GET)("/system/dict/all");
    return res;
  } catch {
    httpErrorHandle();
  }
};

// 上传文件
export const postFileUpload = async (data: any) => {
  try {
    const res = await http(RequestHttpEnum.POST)(
      "/minio/upload",
      data,
      ContentTypeEnum.FORM_DATA
    );
    return res;
  } catch {
    httpErrorHandle();
  }
};

//  可以自定义请求地址 添加
export const postCreate = async (data: any, path: string) => {
  try {
    const res = await http(RequestHttpEnum.POST)(path, data);
    return res;
  } catch {
    httpErrorHandle();
  }
};
