import { defineStore } from "pinia";
import { ref } from "vue";
import { getDictAll, postDictBatch } from "@/api"; // 确保你有这个 API 方法

interface ResItem {
  label: string;
  value: string;
}
interface ResList {
  code: number;
  data: ResItem[];
  executeTime: number;
  message: string;
  timestamp: number;
}

export const useDictStore = defineStore("dict", () => {
  
  // 定义状态
  const dictData = ref<any>();
  const loading = ref<boolean>(false);
  const error = ref<string | null>(null);

  // 定义获取数据的方法
  const fetchDictData = async () => {
    loading.value = true; // 设置加载状态
    error.value = null; // 清除之前的错误

    try {
      // 获取全部的字典
      const res = (await getDictAll()) as unknown as ResList;
      // 提取全部字典字段
      const categories = res.data.map(item => item.value );
      categories.push('country')
      // 获取全部字典的值
      const response = (await postDictBatch({categories})) as unknown as ResList;
      console.log("response ==>", response);
      if (response.code === 200) {
        dictData.value = response.data; // 存储整个字典数据
      } else {
        error.value = `Error: ${response.message}`; // 处理非200状态
      }
    } catch (err: any) {
      error.value = `请求失败: ${err.message}`; // 处理请求错误
    } finally {
      loading.value = false; // 清除加载状态
    }
  };

  return {
    dictData,
    loading,
    error,
    fetchDictData,
  };
});
