import { ref, reactive, onMounted } from "vue";
import { useDictStore } from "@/store/modules/useDictStore/index";
import { getList } from "./useAxios.hook";

// 数据初始化
export const useDataListInit = () => {
  const dictStore = useDictStore();

  // 表单相关
  const formInline = reactive({
    technologicalNeedsName: "",
    technologicalNeedsType: "",
    auditStatus: "",
    createTime: "",
    capital: "",
  });

  const updateInfo = ref();

  // 控制器
  const isCollapse = ref(true);
  const fieldVisible = ref(false);
  const createVisible = ref(false);
  const updateVisible = ref(false);

  // 表格相关
  const currentPage = ref(1);
  const pageSize = ref(10);
  const totalItems = ref(0);
  const tableData = ref([]);
  // 定义所有字段的配置项
  const fieldsConfig = ref([
    { key: "technologicalNeedsName", label: "技术创新需求名称", visible: true },
    { key: "createTime", label: "申请日", visible: true },
    { key: "technologicalNeedsType", label: "需求类型", visible: true },
    { key: "capital", label: "金额预算", visible: true },
    { key: "auditStatus", label: "审核状态", visible: true },
  ]);

  const tempFieldsConfig = ref(JSON.parse(JSON.stringify(fieldsConfig.value)));
  const visibleFields = ref(
    fieldsConfig.value
      .filter((field) => field.visible)
      .map((field) => field.key)
  );

  // 配置
  const formLabelWidth = "120px";

  // 字典
  const review_status = dictStore.dictData.review_status;
  const requirement_type = dictStore.dictData.requirement_type;

  const formFields = [
    {
      label: "需求名称",
      model: "technologicalNeedsName",
      component: "el-input",
      attrs: {
        clearable: true,
        style: "width: 220px",
        placeholder: "请输入需求名称",
      },
    },
    {
      label: "需求类别",
      model: "technologicalNeedsType",
      component: "el-select",
      attrs: {
        placeholder: "选择需求类别",
        clearable: true,
        style: "width: 220px",
      },
      options: requirement_type, // 需要定义可选项
    },
    {
      label: "审核进度",
      model: "auditStatus",
      component: "el-select",
      attrs: {
        placeholder: "选择审核进度",
        clearable: true,
        style: "width: 220px",
      },
      options: review_status, // 需要定义可选项
    },
    {
      label: "申请日",
      model: "createTime",
      component: "el-date-picker",
      attrs: {
        type: "date",
        clearable: true,
        style: "width: 220px",
        placeholder: "选择申请日",
      },
    },
    {
      label: "金额预算",
      model: "capital",
      component: "el-input",
      attrs: {
        clearable: true,
        style: "width: 220px",
        placeholder: "请输入金额预算",
      },
    },
  ];

  const fetchList = async () => {
    const res = (await getList()) as unknown as any;
    if (res.code === 200) {
      tableData.value = res.data.list;
    }
  };

  const onClickReset = () => {
    formInline.technologicalNeedsName = "";
    formInline.technologicalNeedsType = "";
    formInline.auditStatus = "";
    formInline.createTime = "";
    formInline.capital = "";

    // 重置分页
    currentPage.value = 1; // 或者您设定的其他默认页码
    pageSize.value = 10; // 或者您设定的其他默认每页数量

    // 调用 fetchList 以获取重置后的数据
    fetchList();
  };

  const onCollapse = () => {
    isCollapse.value = !isCollapse.value;
  };

  const handleCurrentChange = (val: number) => {
    currentPage.value = val;
    fetchList();
  };

  const onFieldChange = (newTargetKeys: string | string[]) => {
    // 更新临时字段配置
    tempFieldsConfig.value.forEach(
      (field: { visible: boolean; key: string }) => {
        field.visible = newTargetKeys.includes(field.key);
      }
    );
  };

  const saveFieldSettings = () => {
    fieldsConfig.value.forEach((field, index) => {
      field.visible = tempFieldsConfig.value[index].visible;
    });

    // 更新可见字段列表
    visibleFields.value = fieldsConfig.value
      .filter((field) => field.visible)
      .map((field) => field.key);

    fieldVisible.value = false;
    // 可在此处将 visibility 的设置保存到后端
  };

  const handleCreate = () => {
    createVisible.value = false;
    fetchList();
  };

  onMounted(() => {
    fetchList();
  });

  return {
    formInline,
    updateInfo,
    isCollapse,
    fieldVisible,
    createVisible,
    updateVisible,
    currentPage,
    pageSize,
    totalItems,
    tableData,
    visibleFields,
    fieldsConfig,
    formLabelWidth,
    formFields,
    fetchList,
    onClickReset,
    onCollapse,
    handleCurrentChange,
    onFieldChange,
    saveFieldSettings,
    handleCreate,
  };
};
