import { ref, onMounted } from "vue";
import { getList, deleteProject } from "./useAxios.hook";
import { ElMessage, ElMessageBox } from "element-plus";

// 数据初始化
export const useDataListInit = () => {
  // 表格相关
  const currentPage = ref(1);
  const pageSize = ref(10);
  const totalItems = ref(0);
  const tableData = ref([]);
  const componentKey = ref(0);
  const detailsData = ref();
  const descriptionsVisible = ref(false);

  const fieldsConfig = ref([
    { key: "userName", label: "用户名称", visible: true, width: "200" },
    { key: "contactDetails", label: "联系方式", visible: true, width: "300" },
    { key: "patentNumber", label: "专利号", visible: true, width: "200" },
    { key: "createTime", label: "咨询日期", visible: true, width: "200" },
    { key: "description", label: "问题描述", visible: true },
  ]);

  // 字段名与标签的映射
  const labelMapping = {
    country: "国家",
    operationStatus: "操作状态",
    logoResumptionPath: "商标续展申请书文件",
    idCard: "证件号",
    idCardPositivelyPath: "身份证正面文件",
    businessLicensePath: "营业执照文件",
    applicantAddr: "申请人地址",
    applicantType: "申请人类型",
    legislationStatus: "法律状态",
    sealPath: "公章图片路径",
    id: "主键",
    isLogoModify: "商标图样是否变更",
    corporationsName: "企业名称",
    idCardPath: "申请人身份证明文件",
    logoPath: "logo文件",
    contactDetails: "联系方式",
    userId: "用户ID",
    applicant: "申请人",
    authorizationPath: "委托书照片文件",
    logoEnrollmentPath: "商标注册证文件",
    idCardBacksidePath: "身份证反面文件",
    auditStatus: "审核进度",
    logoRegistrationNumber: "商标注册号",
  };

  // 获取数据列表
  const fetchList = async () => {
    const data = {
      pageNumber: currentPage.value,
      pageSize: pageSize.value,
    };
    const res = (await getList(data)) as any;
    if (res.code === 200) {
      tableData.value = res.data.list;
      totalItems.value = res.data.total; // 假设返回的数据中有 total 字段
    }
  };

  // 页面切换
  const handleCurrentChange = (val: number) => {
    currentPage.value = val;
    fetchList();
  };

  const onShow = (row: any) => {
    componentKey.value += 1;
    detailsData.value = row;
    descriptionsVisible.value = true;
  };

  // 删除操作
  const onDelete = (row: any) => {
    ElMessageBox.confirm(
      `请确认要删除用户名为【${row.userName}】的专利维权咨询`,
      "提示信息",
      {
        confirmButtonText: "确认",
        cancelButtonText: "取消",
        type: "warning",
      }
    )
      .then(async () => {
        const res = (await deleteProject(row.id)) as any;
        if (res.code === 200) {
          ElMessage({
            type: "success",
            message: "删除成功",
          });
          fetchList();
        } else {
          ElMessage({
            type: "error",
            message: "删除失败，请联系管理员",
          });
        }
      })
      .catch(() => {
        ElMessage({
          type: "info",
          message: "取消删除",
        });
      });
  };

  onMounted(() => {
    fetchList();
  });

  return {
    detailsData,
    descriptionsVisible,
    labelMapping,
    componentKey,
    currentPage,
    pageSize,
    totalItems,
    tableData,
    fieldsConfig,
    handleCurrentChange,
    onDelete,
    onShow,
  };
};
