import { ref, reactive, onMounted } from "vue";
// import { useDictStore } from "@/store/modules/useDictStore/index";
import { getList, deleteProject } from "./useAxios.hook";
import { ElMessage, ElMessageBox } from "element-plus";

// 数据初始化
export const useDataListInit = () => {
  const path = '/intellectual-property/trademark-amendment/create'
  // const dictStore = useDictStore();
  const componentKey = ref(0);
  // 表单相关
  const formInline = reactive({
    logoRegistrationNumber: "",
  });

  const updateInfo = ref();
  const detailsData = ref();

  // 控制器
  const isCollapse = ref(true);
  const uploadVisible = ref(false);
  const fieldVisible = ref(false);
  const createVisible = ref(false);
  const updateVisible = ref(false);
  const descriptionsVisible = ref(false);

  // 字段名与标签的映射
  const labelMapping = {
    country: "国家",
    operationStatus: "操作状态",
    logoResumptionPath: "商标续展申请书文件",
    idCard: "证件号",
    idCardPositivelyPath: "身份证正面文件",
    businessLicensePath: "营业执照文件",
    applicantAddr: "申请人地址",
    applicantType: "申请人类型",
    legislationStatus: "法律状态",
    sealPath: "公章图片路径",
    id: "主键",
    isLogoModify: "商标图样是否变更",
    corporationsName: "企业名称",
    idCardPath: "申请人身份证明文件",
    logoPath: "logo文件",
    contactDetails: "联系方式",
    userId: "用户ID",
    applicant: "申请人",
    authorizationPath: "委托书照片文件",
    logoEnrollmentPath: "商标注册证文件",
    idCardBacksidePath: "身份证反面文件",
    auditStatus: "审核进度",
    logoRegistrationNumber: "商标注册号",
  };

  // 表格相关
  const currentPage = ref(1);
  const pageSize = ref(10);
  const totalItems = ref(0);
  const tableData = ref([]);
  // 定义所有字段的配置项
  const fieldsConfig = ref([
    { key: "logoRegistrationNumber", label: "注册号", visible: true },
    { key: "applicant", label: "申请人", visible: true },
    { key: "country", label: "国家", visible: true },
    { key: "contactDetails", label: "联系方式", visible: true },
    { key: "applicantAddr", label: "地址", visible: true },
  ]);
  const tempFieldsConfig = ref(JSON.parse(JSON.stringify(fieldsConfig.value)));
  const visibleFields = ref(
    fieldsConfig.value
      .filter((field) => field.visible)
      .map((field) => field.key)
  );

  // 配置
  const formLabelWidth = "120px";

  // 动态表单字段配置
  const formFields = [
    {
      label: "注册号",
      model: "logoRegistrationNumber",
      component: "el-input",
      attrs: {
        clearable: true,
        style: "width: 220px",
        placeholder: "请输入注册号",
      },
    },
  ];

  const fetchList = async () => {
    const data = {
      pageNumber: currentPage.value,
      pageSize: pageSize.value,
      ...formInline,
    };
    const res = (await getList(data)) as unknown as any;
    if (res.code === 200) {
      tableData.value = res.data.list;
    }
  };

  const onClickReset = () => {
    // 重置表单字段
    formInline.logoRegistrationNumber = "";

    // 重置分页
    currentPage.value = 1; // 或者你设定的其他默认页码
    pageSize.value = 10; // 或者你设定的其他默认每页数量

    // 调用 fetchList 以获取重置后的数据
    fetchList();
  };

  const onCollapse = () => {
    isCollapse.value = !isCollapse.value;
  };

  const handleCurrentChange = (val: number) => {
    currentPage.value = val;
    fetchList();
  };

  const onUpload = (row: any) => {
    componentKey.value += 1;
    updateInfo.value = row;
    uploadVisible.value = true;
  }

  const onShow = (row: any) => {
    componentKey.value += 1;
    detailsData.value = row;
    descriptionsVisible.value = true;
  };

  const onUpdate = (row: any) => {
    componentKey.value += 1;
    updateInfo.value = row;
    updateVisible.value = true;
  };

  const onFieldChange = (newTargetKeys: string | string[]) => {
    // 更新临时字段配置
    tempFieldsConfig.value.forEach(
      (field: { visible: boolean; key: string }) => {
        field.visible = newTargetKeys.includes(field.key);
      }
    );
  };

  const saveFieldSettings = () => {
    fieldsConfig.value.forEach((field, index) => {
      field.visible = tempFieldsConfig.value[index].visible;
    });

    // 更新可见字段列表
    visibleFields.value = fieldsConfig.value
      .filter((field) => field.visible)
      .map((field) => field.key);

    fieldVisible.value = false;
    // 可在此处将 visibility 的设置保存到后端
  };

  const handleUpload = () => {
    uploadVisible.value = false;
    fetchList();
  };

  const handleUpdate = () => {
    updateVisible.value = false;
    fetchList();
  }

  // 执行删除商标，记得加提示
  const onDelete = (row: any) => {
    ElMessageBox.confirm(
      "请确认要删除商标名称为【" + row.trademarkName + "】的商标信息",
      "提示信息",
      {
        confirmButtonText: "确认",
        cancelButtonText: "取消",
        type: "warning",
      }
    )
      .then(async () => {
        const res = (await deleteProject(row.id)) as unknown as any;
        if (res.code === 200) {
          ElMessage({
            type: "success",
            message: "删除成功",
          });
          fetchList();
        } else {
          ElMessage({
            type: "error",
            message: "删除失败，请联系管理员",
          });
        }
      })
      .catch(() => {
        ElMessage({
          type: "info",
          message: "取消删除",
        });
      });
  };

  onMounted(() => {
    fetchList();
  });

  return {
    path,
    componentKey,
    formInline,
    updateInfo,
    isCollapse,
    fieldVisible,
    uploadVisible,
    createVisible,
    updateVisible,
    descriptionsVisible,
    currentPage,
    pageSize,
    totalItems,
    tableData,
    visibleFields,
    fieldsConfig,
    formLabelWidth,
    formFields,
    detailsData,
    labelMapping,
    fetchList,
    onClickReset,
    onCollapse,
    handleCurrentChange,
    onUpload,
    handleUpdate,
    onShow,
    onUpdate,
    onFieldChange,
    saveFieldSettings,
    handleUpload,
    onDelete,
  };
};
