import { ref, reactive, onMounted } from "vue";
import { useDictStore } from "@/store/modules/useDictStore/index";
import { getList, deleteProject } from "./useAxios.hook";
import { ElMessage, ElMessageBox } from "element-plus";

// 数据初始化
export const useDataListInit = () => {
  const dictStore = useDictStore();

  const componentKey = ref(0);

  const formInline = reactive({
    patentType: "", // 专利类型
    inventorNames: "", // 发明人
    patentHolderName: "", // 专利权人
    countryCode: "", // 国家/地区
    applicantName: "", // 申请人
    patentAgentFirm: "", // 专利代理机构
    inventionTitle: "", // 专利标题
    applicantAddress: "", // 申请人地址
    patentAgentName: "", // 代理人
    applicationNumber: "", // 申请号
    filingDate: "", // 申请日
    ipcClassification: "", // IPC分类号
    publicationNumber: "", // 公布号
    publicationDate: "", // 公布日
    patentHolderAddress: "", // 专利权人地址
    announcementDate: "" // 授权公告日
  });

  const updateInfo = ref();

  // 控制器
  const isCollapse = ref(true);
  const fieldVisible = ref(false);
  const createVisible = ref(false);
  const updateVisible = ref(false);
  const downloadVisible = ref(false);

  // 表格相关
  const currentPage = ref(1);
  const pageSize = ref(10);
  const totalItems = ref(0);
  const tableData = ref([]);

  // 定义所有字段的配置项
  const fieldsConfig = ref([
    { key: "inventionTitle", label: "专利标题", visible: true },
    { key: "applicationNumber", label: "申请号", visible: true },
    { key: "filingDate", label: "申请日", visible: true },
    { key: "publicationNumber", label: "公布号", visible: true },
    { key: "publicationDate", label: "公布日", visible: true },
    { key: "applicantName", label: "申请人", visible: true },
    { key: "patentHolderName", label: "专利权人", visible: true },
    { key: "patentType", label: "专利类型", visible: false },
    { key: "inventorNames", label: "发明人", visible: false },
    { key: "countryCode", label: "国家/地区", visible: false },
    { key: "patentAgentFirm", label: "专利代理机构", visible: false },
    { key: "applicantAddress", label: "申请人地址", visible: false },
    { key: "patentAgentName", label: "代理人", visible: false },
    { key: "ipcClassification", label: "IPC分类号", visible: false },
    { key: "patentHolderAddress", label: "专利权人地址", visible: false },
    { key: "announcementDate", label: "授权公告日", visible: false },
  ]);

  const tempFieldsConfig = ref(JSON.parse(JSON.stringify(fieldsConfig.value)));
  const visibleFields = ref(
    fieldsConfig.value
      .filter((field) => field.visible)
      .map((field) => field.key)
  );

  // 配置
  const formLabelWidth = "120px";

  // 字典
  const patentsType = dictStore.dictData.patents_type;

  const formFields = [
    {
      label: "专利类型",
      model: "patentType", // 如果在参考中未定义，需要填写可选项
      component: "el-select",
      attrs: {
        placeholder: "选择专利类型",
        clearable: true,
        style: "width: 220px",
      },
      options: patentsType, // 需要提前定义可选项
    },
    {
      label: "发明人",
      model: "inventorNames", // 从参考中获取
      component: "el-input",
      attrs: {
        clearable: true,
        style: "width: 220px",
        placeholder: "请输入发明人",
      },
    },
    {
      label: "专利权人",
      model: "patentHolderName", // 从参考中获取
      component: "el-input",
      attrs: {
        clearable: true,
        style: "width: 220px",
        placeholder: "请输入专利权人",
      },
    },
    {
      label: "国家/地区",
      model: "countryCode", // 未在参考中对应，留空
      component: "el-input",
      attrs: {
        clearable: true,
        style: "width: 220px",
        placeholder: "请输入国家地区",
      },
    },
    {
      label: "申请人",
      model: "applicantName", // 未在参考中对应，留空
      component: "el-input",
      attrs: {
        clearable: true,
        style: "width: 220px",
        placeholder: "请输入申请人",
      },
    },
    {
      label: "专利代理机构",
      model: "patentAgentFirm", // 从参考中获取
      component: "el-input",
      attrs: {
        clearable: true,
        style: "width: 220px",
        placeholder: "请输入专利代理机构",
      },
    },
    {
      label: "专利标题",
      model: "inventionTitle", // 未在参考中对应，留空
      component: "el-input",
      attrs: {
        clearable: true,
        style: "width: 220px",
        placeholder: "请输入专利标题",
      },
    },
    {
      label: "申请人地址",
      model: "applicantAddress", // 未在参考中对应，留空
      component: "el-input",
      attrs: {
        clearable: true,
        style: "width: 220px",
        placeholder: "请输入申请人地址",
      },
    },
    {
      label: "代理人",
      model: "patentAgentName", // 未在参考中对应，留空
      component: "el-input",
      attrs: {
        clearable: true,
        style: "width: 220px",
        placeholder: "请输入代理人",
      },
    },
    {
      label: "申请号",
      model: "applicationNumber", // 从参考中获取
      component: "el-input",
      attrs: {
        clearable: true,
        style: "width: 220px",
        placeholder: "请输入申请号",
      },
    },
    {
      label: "申请日",
      model: "filingDate", // 从参考中获取
      component: "el-date-picker",
      attrs: {
        type: "date",
        clearable: true,
        style: "width: 220px",
        placeholder: "选择申请日",
      },
    },
    {
      label: "IPC分类号",
      model: "ipcClassification", // 未在参考中对应，留空
      component: "el-input",
      attrs: {
        clearable: true,
        style: "width: 220px",
        placeholder: "请输入IPC分类号",
      },
    },
    {
      label: "公布号",
      model: "publicationNumber", // 未在参考中对应，留空
      component: "el-input",
      attrs: {
        clearable: true,
        style: "width: 220px",
        placeholder: "请输入公布号",
      },
    },
    {
      label: "公布日",
      model: "publicationDate", // 未在参考中对应，留空
      component: "el-date-picker",
      attrs: {
        type: "date",
        clearable: true,
        style: "width: 220px",
        placeholder: "选择公布日",
      },
    },
    {
      label: "专利权人地址",
      model: "patentHolderAddress", // 未在参考中对应，留空
      component: "el-input",
      attrs: {
        clearable: true,
        style: "width: 220px",
        placeholder: "请输入专利权人地址",
      },
    },
    {
      label: "授权公告日",
      model: "announcementDate", // 未在参考中对应，留空
      component: "el-date-picker",
      attrs: {
        type: "date",
        clearable: true,
        style: "width: 220px",
        placeholder: "选择授权公告日",
      },
    },
  ];

  const fetchList = async () => {
    const data = {
      pageNumber: currentPage.value,
      pageSize: pageSize.value,
      ...formInline,
    };
    const res = (await getList(data)) as unknown as any;
    if (res.code === 200) {
      tableData.value = res.data.list;
    }
  };

  const onClickReset = () => {
    // 重置表单字段
    formInline.patentType = "";             // 专利类型
    formInline.inventorNames = "";           // 发明人
    formInline.patentHolderName = "";        // 专利权人
    formInline.countryCode = "";              // 国家/地区
    formInline.applicantName = "";            // 申请人
    formInline.patentAgentFirm = "";         // 专利代理机构
    formInline.inventionTitle = "";           // 专利标题
    formInline.applicantAddress = "";         // 申请人地址
    formInline.patentAgentName = "";          // 代理人
    formInline.applicationNumber = "";        // 申请号
    formInline.filingDate = "";               // 申请日
    formInline.ipcClassification = "";        // IPC分类号
    formInline.publicationNumber = "";        // 公布号
    formInline.publicationDate = "";          // 公布日
    formInline.patentHolderAddress = "";      // 专利权人地址
    formInline.announcementDate = ""; //  授权公告日
    // 重置分页
    currentPage.value = 1;                   // 或者您设定的其他默认页码
    pageSize.value = 10;                      // 或者您设定的其他默认每页数量
  
    // 调用 fetchList 以获取重置后的数据
    fetchList();
  };

  const onCollapse = () => {
    isCollapse.value = !isCollapse.value;
  };

  const handleCurrentChange = (val: number) => {
    currentPage.value = val;
    fetchList();
  };

  const onUpdate = (row: any) => {
    componentKey.value += 1;
    updateInfo.value = row;
    updateVisible.value = true;
  };

  const onDownload = (row: any) => {
    console.log("onDownload ===>", row);
    updateInfo.value = row;
    downloadVisible.value = true;
  };

  const onFieldChange = (newTargetKeys: string | string[]) => {
    // 更新临时字段配置
    tempFieldsConfig.value.forEach(
      (field: { visible: boolean; key: string }) => {
        field.visible = newTargetKeys.includes(field.key);
      }
    );
  };

  const saveFieldSettings = () => {
    fieldsConfig.value.forEach((field, index) => {
      field.visible = tempFieldsConfig.value[index].visible;
    });

    // 更新可见字段列表
    visibleFields.value = fieldsConfig.value
      .filter((field) => field.visible)
      .map((field) => field.key);

    fieldVisible.value = false;
    // 可在此处将 visibility 的设置保存到后端
  };

  const handleCreate = () => {
    createVisible.value = false;
  };

  const handleUpdate = () => {
    updateVisible.value = false;
    fetchList();
  };

  // 执行删除专利，记得加提示
  const onDelete = (row: any) => {
    ElMessageBox.confirm(
      "请确认要删除专利名称为【" + row.inventionTitle + "】的专利信息",
      "提示信息",
      {
        confirmButtonText: "确认",
        cancelButtonText: "取消",
        type: "warning",
      }
    )
      .then(async () => {
        const res = (await deleteProject(row.id)) as unknown as any;
        if (res.code === 200) {
          ElMessage({
            type: "success",
            message: "删除成功",
          });
          fetchList();
        } else {
          ElMessage({
            type: "error",
            message: "删除失败，请联系管理员",
          });
        }
      })
      .catch(() => {
        ElMessage({
          type: "info",
          message: "取消删除",
        });
      });
  };

  onMounted(() => {
    fetchList();
  });

  return {
    formInline,
    updateInfo,
    isCollapse,
    fieldVisible,
    createVisible,
    updateVisible,
    downloadVisible,
    currentPage,
    pageSize,
    totalItems,
    tableData,
    visibleFields,
    fieldsConfig,
    formLabelWidth,
    formFields,
    componentKey,
    fetchList,
    onClickReset,
    onCollapse,
    handleCurrentChange,
    onUpdate,
    onDownload,
    onFieldChange,
    saveFieldSettings,
    handleCreate,
    handleUpdate,
    onDelete,
  };
};
