import { ref, reactive, onMounted } from "vue";
import { useDictStore } from "@/store/modules/useDictStore/index";
import { getList, postUpdate, deleteProject } from "./useAxios.hook";
import { ElMessage, ElMessageBox } from "element-plus";

// 数据初始化
export const useDataListInit = () => {
  const dictStore = useDictStore();

  // 表单相关
  const formInline = reactive({
    technologicalNeedsName: "",
    technologicalNeedsType: "",
    auditStatus: "",
    createTime: "",
    capital: "",
  });

  const updateInfo = ref();

  const componentKey = ref(0);
  const detailsData = ref();
  const descriptionsVisible = ref(false);

  // 控制器
  const isCollapse = ref(true);
  const fieldVisible = ref(false);
  const createVisible = ref(false);
  const updateVisible = ref(false);

  // 表格相关
  const currentPage = ref(1);
  const pageSize = ref(10);
  const totalItems = ref(0);
  const tableData = ref([]);
  // 定义所有字段的配置项
  const fieldsConfig = ref([
    { key: "technologicalNeedsName", label: "技术创新需求名称", visible: true },
    { key: "createTime", label: "申请日", visible: true },
    { key: "technologicalNeedsType", label: "需求类型", visible: true },
    { key: "capital", label: "金额预算", visible: true },
    { key: "auditStatus", label: "审核状态", visible: true },
  ]);

  const tempFieldsConfig = ref(JSON.parse(JSON.stringify(fieldsConfig.value)));
  const visibleFields = ref(
    fieldsConfig.value
      .filter((field) => field.visible)
      .map((field) => field.key)
  );

  // 配置
  const formLabelWidth = "120px";

  // 字典
  const review_status = dictStore.dictData.review_status;
  const requirement_type = dictStore.dictData.requirement_type;

  const labelMapping = {
    country: "国家",
    operationStatus: "操作状态",
    logoResumptionPath: "商标续展申请书文件",
    idCard: "证件号",
    idCardPositivelyPath: "身份证正面文件",
    businessLicensePath: "营业执照文件",
    applicantAddr: "申请人地址",
    applicantType: "申请人类型",
    legislationStatus: "法律状态",
    sealPath: "公章图片路径",
    id: "主键",
    isLogoModify: "商标图样是否变更",
    corporationsName: "企业名称",
    idCardPath: "申请人身份证明文件",
    logoPath: "logo文件",
    contactDetails: "联系方式",
    userId: "用户ID",
    applicant: "申请人",
    authorizationPath: "委托书照片文件",
    logoEnrollmentPath: "商标注册证文件",
    idCardBacksidePath: "身份证反面文件",
    auditStatus: "审核进度",
    logoRegistrationNumber: "商标注册号",
  };


  const formFields = [
    {
      label: "需求名称",
      model: "technologicalNeedsName",
      component: "el-input",
      attrs: {
        clearable: true,
        style: "width: 220px",
        placeholder: "请输入需求名称",
      },
    },
    {
      label: "需求类别",
      model: "technologicalNeedsType",
      component: "el-select",
      attrs: {
        placeholder: "选择需求类别",
        clearable: true,
        style: "width: 220px",
      },
      options: requirement_type, // 需要定义可选项
    },
    {
      label: "审核进度",
      model: "auditStatus",
      component: "el-select",
      attrs: {
        placeholder: "选择审核进度",
        clearable: true,
        style: "width: 220px",
      },
      options: review_status, // 需要定义可选项
    },
    {
      label: "申请日",
      model: "createTime",
      component: "el-date-picker",
      attrs: {
        type: "date",
        clearable: true,
        style: "width: 220px",
        placeholder: "选择申请日",
      },
    },
    {
      label: "金额预算",
      model: "capital",
      component: "el-input",
      attrs: {
        clearable: true,
        style: "width: 220px",
        placeholder: "请输入金额预算",
      },
    },
  ];

  const fetchList = async () => {
    const data = {
      pageNumber: currentPage.value,
      pageSize: pageSize.value,
      ...formInline,
    };
    const res = (await getList(data)) as unknown as any;
    if (res.code === 200) {
      tableData.value = res.data.list;
    }
  };

  const onClickReset = () => {
    formInline.technologicalNeedsName = "";
    formInline.technologicalNeedsType = "";
    formInline.auditStatus = "";
    formInline.createTime = "";
    formInline.capital = "";

    // 重置分页
    currentPage.value = 1; // 或者您设定的其他默认页码
    pageSize.value = 10; // 或者您设定的其他默认每页数量

    // 调用 fetchList 以获取重置后的数据
    fetchList();
  };

  const onCollapse = () => {
    isCollapse.value = !isCollapse.value;
  };

  const handleCurrentChange = (val: number) => {
    currentPage.value = val;
    fetchList();
  };
  const onShow = (row: any) => {
    componentKey.value += 1;
    detailsData.value = row;
    descriptionsVisible.value = true;
  };

  const onReject = () => {
    ElMessageBox.prompt("请说明驳回原因", "审核未通过", {
      confirmButtonText: "提交",
      cancelButtonText: "取消",
    })
      .then(async ({ value }) => {
        const data = {
          id: detailsData.value.id,
          auditStatus: "2",
          rejectInfo: value
        };
        const res = (await postUpdate(data)) as unknown as any;
        if (res.code === 200) {
          ElMessage({
            type: "success",
            message: "操作成功",
          });
          descriptionsVisible.value = false;
          fetchList();
        } else {
          ElMessage({
            type: "error",
            message: "操作失败，请联系管理员",
          });
        }
      })
      .catch(() => {
        ElMessage({
          type: "info",
          message: "取消驳回",
        });
      });
  };

  const onUpdate = async () => {
    // if (isExamine) {
    ElMessageBox.confirm(
      "请确认要通过名称为【" +
        detailsData.value.technologicalNeedsName +
        "】的专利运营需求审核",
      "提示信息",
      {
        confirmButtonText: "通过",
        cancelButtonText: "取消",
        type: "warning",
      }
    )
      .then(async () => {
        const data = {
          id: detailsData.value.id,
          auditStatus: "1",
        };
        const res = (await postUpdate(data)) as unknown as any;
        if (res.code === 200) {
          ElMessage({
            type: "success",
            message: "操作成功",
          });
          descriptionsVisible.value = false;
          fetchList();
        } else {
          ElMessage({
            type: "error",
            message: "操作失败，请联系管理员",
          });
        }
      })
      .catch(() => {
        ElMessage({
          type: "info",
          message: "取消删除",
        });
      });
  };

  const onFieldChange = (newTargetKeys: string | string[]) => {
    // 更新临时字段配置
    tempFieldsConfig.value.forEach(
      (field: { visible: boolean; key: string }) => {
        field.visible = newTargetKeys.includes(field.key);
      }
    );
  };

  const saveFieldSettings = () => {
    fieldsConfig.value.forEach((field, index) => {
      field.visible = tempFieldsConfig.value[index].visible;
    });

    // 更新可见字段列表
    visibleFields.value = fieldsConfig.value
      .filter((field) => field.visible)
      .map((field) => field.key);

    fieldVisible.value = false;
    // 可在此处将 visibility 的设置保存到后端
  };

  const handleCreate = () => {
    createVisible.value = false;
    fetchList();
  };

  // 执行删除专利，记得加提示
  const onDelete = (row: any) => {
    ElMessageBox.confirm(
      "请确认要删除专利名称为【" + row.patentsName + "】的专利信息",
      "提示信息",
      {
        confirmButtonText: "确认",
        cancelButtonText: "取消",
        type: "warning",
      }
    )
      .then(async () => {
        const res = (await deleteProject(row.id)) as unknown as any;
        if (res.code === 200) {
          ElMessage({
            type: "success",
            message: "删除成功",
          });
          fetchList();
        } else {
          ElMessage({
            type: "error",
            message: "删除失败，请联系管理员",
          });
        }
      })
      .catch(() => {
        ElMessage({
          type: "info",
          message: "取消删除",
        });
      });
  };

  onMounted(() => {
    fetchList();
  });

  return {
    labelMapping,
    componentKey,
    detailsData,
    descriptionsVisible,
    formInline,
    updateInfo,
    isCollapse,
    fieldVisible,
    createVisible,
    updateVisible,
    currentPage,
    pageSize,
    totalItems,
    tableData,
    visibleFields,
    fieldsConfig,
    formLabelWidth,
    formFields,
    fetchList,
    onClickReset,
    onCollapse,
    handleCurrentChange,
    onShow,
    onUpdate,
    onReject,
    onFieldChange,
    saveFieldSettings,
    handleCreate,
    onDelete,
  };
};
